#include <math.h>
#include "common.h"
#include "deviic.h"
#include <linux/i2c-dev.h>
#include <sys/ioctl.h>

static int i2c_fd = -1;       // I2C设备文件描述符

// 初始化I2C总线
bool i2c_init(int bus_number) {
    char filename[20];
    snprintf(filename, sizeof(filename), "/dev/i2c-%d", bus_number);
    i2c_fd = open(filename, O_RDWR);
    if (i2c_fd < 0) {
        perror("Failed to open I2C bus");
        return false;
    }
    return true;
}

// 设置I2C从设备地址
bool i2c_set_slave_address(uint8_t address) {
    if (ioctl(i2c_fd, I2C_SLAVE, address) < 0) {
        perror("Failed to set slave address");
        return false;
    }
    return true;
}

// 通用I2C写操作（寄存器地址 + 2字节数据）
bool i2c_write_reg(uint8_t reg_addr, uint16_t data) {
    uint8_t buf[3] = {reg_addr, (data >> 8), (data & 0xFF)};
    if (write(i2c_fd, buf, 3) != 3) {
        perror("I2C write failed");
        return false;
    }
    return true;
}

// 通用I2C读操作（寄存器地址 + 读取2字节数据）
bool i2c_read_reg(uint8_t reg_addr, uint16_t *data) {
    // 发送寄存器地址
    if (write(i2c_fd, &reg_addr, 1) != 1) {
        perror("Failed to send register address");
        return false;
    }
    // 读取2字节数据
    if (read(i2c_fd, data, 2) != 2) {
        perror("I2C read failed");
        return false;
    }
    return true;
}

// 关闭I2C连接
void i2c_close() {
    if (i2c_fd != -1) {
        close(i2c_fd);
        i2c_fd = -1;
    }
}