#include <math.h>
#include "common.h"
#include "INA226.h"
float currentLSB ;

// 初始化INA226
bool INA226_begin(int bus_number) {
    if (!i2c_init(bus_number)) return false;
    if (!i2c_set_slave_address(INA226_ADDRESS)) {
        i2c_close();
        return false;
    }
    return true;
}

// 配置INA226寄存器
bool INA226_configure() {
    uint16_t config = 0x4127; // 默认配置：16次平均，1.1ms转换，连续模式
    return i2c_write_reg(INA226_REG_CONFIG, config);
}

// 校准INA226
bool INA226_calibrate(float rShuntValue, float iMaxExpected) {
    currentLSB = iMaxExpected / 32767.0f; // 计算电流LSB
    uint16_t calibration = (uint16_t)(0.00512f / (currentLSB * rShuntValue));
    return i2c_write_reg(INA226_REG_CALIBRATION, calibration);
}

// 读取总线电压（单位：V）
float INA226_readBusVoltage() {
    uint16_t raw;
    if (!i2c_read_reg(INA226_REG_BUSVOLTAGE, &raw)) return 0.0f;
    return ((raw >> 3) * 0.00125f); // 高13位有效，1.25mV/LSB
}

// 读取电流（单位：A）
float INA226_readCurrent() {
    uint16_t raw;
    if (!i2c_read_reg(INA226_REG_CURRENT, &raw)) return 0.0f;
    return ((int16_t)raw * currentLSB); // 转换为有符号数
}

void INA226_end(void) {
    i2c_close();
}
